## Example projects

This directory contains example projects that demonstrate how to use PigFrame with different python game development libraries.

- [Control A Ball (Pygame version)](./pygame_control_a_ball/)

- [Control A Ball (Pyxel version)](./pyxel_control_a_ball/)

- [Simple Top-Down Shooting (Pyxel version)](./pyxel_2d_shooting/)
